@@ -1,5 +1,5 @@
 # fields, Tools for spatial data
-# Copyright 2004-2007, Institute for Mathematics Applied Geosciences
+# Copyright 2004-2011, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
 "predict.Krig" <- function(object, x = NULL, Z = NULL, 
@@ -9,8 +9,9 @@
     #NOTE: most of this function is figuring out what to do!
     #
     # check that derivative is not called
-      if( !is.null( list(...)$derivative)) {
-         stop("For derivatives use predict.derivative") }
+    if (!is.null(list(...)$derivative)) {
+        stop("For derivatives use predict.derivative")
+    }
     # y is full data yM are the data collapsed to replicate means
     # if new data is not passed then copy from the object
     if (is.null(y) & is.null(yM)) {
