@@ -3,7 +3,7 @@
 c derivative of  radial basis function
 c  r(d2)=  d2**(par(1)   or  par(2).ne. 0   d2**par(1) log( d2)  
 c
-       real*8 d2(n), par(2), dtemp, p1,p2
+       double precision d2(n), par(2), dtemp, p1,p2
        integer n
        if( int(par(2)).eq.0) then
 
